==> WinBinder-0.30.101.tgz: Code/tests/tabs.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG3001")) define("IDD_DLG3001", 3001);
if(!defined("IDC_TREEVIEW3004")) define("IDC_TREEVIEW3004", 3061);
if(!defined("IDC_STATIC3062")) define("IDC_STATIC3062", 3062);
if(!defined("IDC_BUTTON3063")) define("IDC_BUTTON3063", 3063);

// Create window

wbtemp_create_item($maintab, "Treeview");

// Insert controls

wb_create_control($maintab, TreeView, "", 4, 6, 303, 160, IDC_TREEVIEW3004, WBC_VISIBLE | WBC_ENABLED, 0);
wb_create_control($maintab, Label, "(Values)", 4, 172, 463, 41, IDC_STATIC3062, WBC_VISIBLE | WBC_ENABLED, 0);
wb_create_control($maintab, PushButton, "Set", 317, 9, 51, 21, IDC_BUTTON3063, WBC_VISIBLE | WBC_ENABLED, 0);

// End controls


// Control identifiers

if(!defined("IDD_DLG2001")) define("IDD_DLG2001", 2001);
if(!defined("IDC_COMBOBOX2010")) define("IDC_COMBOBOX2010", 2010);
if(!defined("IDC_LISTBOX2018")) define("IDC_LISTBOX2018", 2018);
if(!defined("IDC_LISTVIEW2027")) define("IDC_LISTVIEW2027", 2027);
if(!defined("IDC_EDIT2064")) define("IDC_EDIT2064", 2064);

// Create window

wbtemp_create_item($maintab, "Test list");

// Insert controls

wb_create_control($maintab, ListView, "", 4, 6, 327, 167, IDC_LISTVIEW2027, WBC_VISIBLE | WBC_ENABLED | WBC_SORT, 1);
wb_create_control($maintab, ComboBox, "", 336, 3, 131, 196, IDC_COMBOBOX2010, WBC_VISIBLE | WBC_ENABLED, 1);
wb_create_control($maintab, ListBox, "", 336, 29, 202, 137, IDC_LISTBOX2018, WBC_VISIBLE | WBC_ENABLED, 1);
wb_create_control($maintab, EditBox, "", 4, 177, 534, 67, IDC_EDIT2064, WBC_VISIBLE | WBC_ENABLED | WBC_MULTILINE | WBC_READONLY, 1);

// End controls


// Control identifiers

if(!defined("IDD_DLG4001")) define("IDD_DLG4001", 4001);
if(!defined("IDC_PROGRESSBAR4007")) define("IDC_PROGRESSBAR4007", 4007);
if(!defined("IDC_SLIDER4011")) define("IDC_SLIDER4011", 4011);
if(!defined("IDC_GROUPBOX4012")) define("IDC_GROUPBOX4012", 4012);
if(!defined("IDC_RADIOBUTTON4014")) define("IDC_RADIOBUTTON4014", 4014);
if(!defined("IDC_RADIOBUTTON4015")) define("IDC_RADIOBUTTON4015", 4015);
if(!defined("IDC_STATIC4019")) define("IDC_STATIC4019", 4019);
if(!defined("IDC_TOOLBAR4025")) define("IDC_TOOLBAR4025", 4025);
if(!defined("IDD_DLG4027")) define("IDD_DLG4027", 4027);
if(!defined("ID_TREE")) define("ID_TREE", 801);
if(!defined("IDC_HSCROLL4026")) define("IDC_HSCROLL4026", 4026);
if(!defined("IDC_UPDOWN4028")) define("IDC_UPDOWN4028", 4028);
if(!defined("IDC_EDIT4030")) define("IDC_EDIT4030", 4030);
if(!defined("IDC_CHECKBOX4034")) define("IDC_CHECKBOX4034", 4034);
if(!defined("IDC_RADIOBUTTON4016")) define("IDC_RADIOBUTTON4016", 4016);
if(!defined("IDC_STATIC4048")) define("IDC_STATIC4048", 4048);
if(!defined("IDC_CHECKBOX4049")) define("IDC_CHECKBOX4049", 4049);
if(!defined("IDC_VSCROLL4051")) define("IDC_VSCROLL4051", 4051);
if(!defined("IDC_EDIT4052")) define("IDC_EDIT4052", 4052);
if(!defined("IDC_LISTBOX4053")) define("IDC_LISTBOX4053", 4053);
if(!defined("IDC_COMBOBOX4054")) define("IDC_COMBOBOX4054", 4054);
if(!defined("IDC_LISTBOX4055")) define("IDC_LISTBOX4055", 4055);
if(!defined("IDC_HSCROLL4056")) define("IDC_HSCROLL4056", 4056);
if(!defined("IDC_EDIT4057")) define("IDC_EDIT4057", 4057);
if(!defined("IDC_EDIT4058")) define("IDC_EDIT4058", 4058);
if(!defined("IDC_EDIT4059")) define("IDC_EDIT4059", 4059);
if(!defined("IDC_EDIT4060")) define("IDC_EDIT4060", 4060);
if(!defined("IDC_RICHEDIT4061")) define("IDC_RICHEDIT4061", 4061);
if(!defined("IDC_RICHEDIT4062")) define("IDC_RICHEDIT4062", 4062);
if(!defined("IDC_STATIC4063")) define("IDC_STATIC4063", 4063);
if(!defined("IDC_STATIC4064")) define("IDC_STATIC4064", 4064);
if(!defined("IDC_EDIT4065")) define("IDC_EDIT4065", 4065);

// Create window

wbtemp_create_item($maintab, "Test values");

// Insert controls

wb_create_control($maintab, Frame, "Group box", 4, 6, 111, 141, IDC_GROUPBOX4012, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Gauge, "IDC_PROGRESSBAR4007", 155, 36, 104, 14, IDC_PROGRESSBAR4007, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Slider, "IDC_SLIDER4011", 120, 68, 146, 26, IDC_SLIDER4011, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &1", 19, 29, 92, 14, IDC_RADIOBUTTON4014, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &2", 19, 50, 92, 19, IDC_RADIOBUTTON4015, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "0", 120, 36, 27, 14, IDC_STATIC4019, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT, 2);
wb_create_control($maintab, ScrollBar, "IDC_HSCROLL4026", 125, 9, 137, 16, IDC_HSCROLL4026, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "0", 120, 104, 40, 19, IDC_EDIT4030, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, Spinner, "", 163, 104, 16, 19, IDC_UPDOWN4028, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, CheckBox, "Checkbox 1", 19, 100, 92, 14, IDC_CHECKBOX4034, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &3", 19, 73, 92, 19, IDC_RADIOBUTTON4016, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "(Values)", 4, 208, 282, 26, IDC_STATIC4048, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, CheckBox, "Checkbox 2", 19, 121, 92, 14, IDC_CHECKBOX4049, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ScrollBar, "", 271, 4, 16, 127, IDC_VSCROLL4051, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "0", 206, 104, 40, 19, IDC_EDIT4052, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, ListBox, "", 297, 4, 75, 52, IDC_LISTBOX4053, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ComboBox, "", 377, 4, 131, 196, IDC_COMBOBOX4054, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ListBox, "", 377, 31, 131, 21, IDC_LISTBOX4055, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ScrollBar, "IDC_HSCROLL4056", 120, 131, 146, 16, IDC_HSCROLL4056, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "Pack my box with five dozen liquor jugs", 4, 154, 131, 21, IDC_EDIT4057, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "", 4, 177, 131, 21, IDC_EDIT4058, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY, 2);
wb_create_control($maintab, EditBox, "", 140, 154, 146, 21, IDC_EDIT4059, WBC_VISIBLE | WBC_ENABLED | WBC_MASKED, 2);
wb_create_control($maintab, RTFEditBox, "", 297, 121, 243, 55, IDC_RICHEDIT4061, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY, 2);
wb_create_control($maintab, RTFEditBox, "", 297, 182, 243, 55, IDC_RICHEDIT4062, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "&Digits only:", 140, 182, 55, 21, IDC_STATIC4063, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT, 2);
wb_create_control($maintab, EditBox, "", 197, 177, 90, 21, IDC_EDIT4060, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, EditBox, "", 297, 62, 243, 55, IDC_EDIT4065, WBC_VISIBLE | WBC_DISABLED | WBC_MULTILINE, 2);
wb_create_control($maintab, Label, "Drag me:", 169, 52, 60, 14, IDC_STATIC4064, WBC_VISIBLE | WBC_ENABLED | WBC_CENTER, 2);

// End controls


// Control identifiers

if(!defined("IDD_DLG5001")) define("IDD_DLG5001", 5001);
if(!defined("IDC_GROUPBOX5012")) define("IDC_GROUPBOX5012", 5012);
if(!defined("IDC_TOOLBAR5025")) define("IDC_TOOLBAR5025", 5025);
if(!defined("IDD_DLG5027")) define("IDD_DLG5027", 5027);
if(!defined("IDC_SHAPE5056")) define("IDC_SHAPE5056", 5056);
if(!defined("IDC_SHAPE5057")) define("IDC_SHAPE5057", 5057);
if(!defined("IDC_SHAPE5058")) define("IDC_SHAPE5058", 5058);
if(!defined("IDC_STATIC5060")) define("IDC_STATIC5060", 5060);
if(!defined("IDC_SHAPE5061")) define("IDC_SHAPE5061", 5061);
if(!defined("IDC_STATIC5062")) define("IDC_STATIC5062", 5062);
if(!defined("IDC_STATIC5063")) define("IDC_STATIC5063", 5063);
if(!defined("IDC_STATIC5064")) define("IDC_STATIC5064", 5064);

// Create window

wbtemp_create_item($maintab, "Static controls");

// Insert controls

wb_create_control($maintab, Frame, "", 126, 8, 120, 68, IDC_SHAPE5058, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "Group box", 4, 4, 111, 72, IDC_GROUPBOX5012, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "", 327, 9, 131, 3, IDC_SHAPE5056, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "", 468, 9, 1, 62, IDC_SHAPE5057, WBC_VISIBLE | WBC_ENABLED, 3);
$_tmp_ctrl_ = wb_create_control($maintab, Frame, "dn_arrow.bmp", 6, 141, 113, 45, IDC_STATIC5062, WBC_VISIBLE | WBC_ENABLED | WBC_IMAGE | WBC_CENTER, 3);
wb_set_image($_tmp_ctrl_, '../res/dn_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($maintab, Label, "This text is centered.", 409, 82, 61, 36, IDC_STATIC5060, WBC_VISIBLE | WBC_ENABLED | WBC_CENTER, 3);
wb_create_control($maintab, Label, "'Sunken' text is ignored. For a sunken frame...", 4, 85, 111, 45, IDC_SHAPE5061, WBC_VISIBLE | WBC_ENABLED, 3);
$_tmp_ctrl_ = wb_create_control($maintab, Frame, "hyper.ico", 125, 141, 113, 45, IDC_STATIC5063, WBC_VISIBLE | WBC_ENABLED | WBC_IMAGE | WBC_CENTER, 3);
wb_set_image($_tmp_ctrl_, '../res/hyper.ico', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($maintab, Frame, "...use style SS_BITMAP or SS_ICON.", 125, 85, 221, 45, IDC_STATIC5064, WBC_VISIBLE | WBC_ENABLED | WBC_IMAGE | WBC_CENTER, 3);

// End controls

?>

==> WinBinder-0.31.104.tgz: Code/tests/tabs.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG3001")) define("IDD_DLG3001", 3001);
if(!defined("IDC_TREEVIEW3004")) define("IDC_TREEVIEW3004", 3061);
if(!defined("IDC_STATIC3062")) define("IDC_STATIC3062", 3062);
if(!defined("IDC_BUTTON3063")) define("IDC_BUTTON3063", 3063);
if(!defined("IDC_TABCONTROL3064")) define("IDC_TABCONTROL3064", 3064);
if(!defined("IDC_TABCONTROL3065")) define("IDC_TABCONTROL3065", 3065);

// Create window

wbtemp_create_item($maintab, "Treeview");

// Insert controls

wb_create_control($maintab, TreeView, "", 4, 6, 303, 160, IDC_TREEVIEW3004, WBC_VISIBLE | WBC_ENABLED, 0);
wb_create_control($maintab, Label, "(Values)", 4, 172, 463, 41, IDC_STATIC3062, WBC_VISIBLE | WBC_ENABLED | WBC_LINES, 0);
wb_create_control($maintab, PushButton, "Set", 317, 9, 51, 21, IDC_BUTTON3063, WBC_VISIBLE | WBC_ENABLED, 0);
wb_create_control($maintab, TabControl, "", 321, 45, 146, 50, IDC_TABCONTROL3064, WBC_VISIBLE | WBC_ENABLED, 0);
wb_create_control($maintab, TabControl, "Hi", 321, 106, 146, 50, IDC_TABCONTROL3065, WBC_VISIBLE | WBC_ENABLED, 0);

// End controls


// Control identifiers

if(!defined("IDD_DLG2001")) define("IDD_DLG2001", 2001);
if(!defined("IDC_COMBOBOX2010")) define("IDC_COMBOBOX2010", 2010);
if(!defined("IDC_LISTBOX2018")) define("IDC_LISTBOX2018", 2018);
if(!defined("IDC_LISTVIEW2027")) define("IDC_LISTVIEW2027", 2027);
if(!defined("IDC_EDIT2064")) define("IDC_EDIT2064", 2064);
if(!defined("IDC_LISTVIEW2067")) define("IDC_LISTVIEW2067", 2067);

// Create window

wbtemp_create_item($maintab, "Test list");

// Insert controls

wb_create_control($maintab, ListView, "", 4, 6, 327, 160, IDC_LISTVIEW2027, WBC_VISIBLE | WBC_ENABLED | WBC_SORT | WBC_LINES | WBC_CHECKBOXES, 1);
wb_create_control($maintab, ComboBox, "", 336, 3, 131, 196, IDC_COMBOBOX2010, WBC_VISIBLE | WBC_ENABLED, 1);
wb_create_control($maintab, ListBox, "", 336, 29, 191, 137, IDC_LISTBOX2018, WBC_VISIBLE | WBC_ENABLED, 1);
wb_create_control($maintab, EditBox, "", 4, 177, 267, 67, IDC_EDIT2064, WBC_VISIBLE | WBC_ENABLED | WBC_LINES | WBC_READONLY, 1);
wb_create_control($maintab, ListView, "", 282, 177, 247, 72, IDC_LISTVIEW2067, WBC_VISIBLE | WBC_ENABLED | WBC_SORT, 1);

// End controls


// Control identifiers

if(!defined("IDD_DLG4001")) define("IDD_DLG4001", 4001);
if(!defined("IDC_PROGRESSBAR4007")) define("IDC_PROGRESSBAR4007", 4007);
if(!defined("IDC_SLIDER4011")) define("IDC_SLIDER4011", 4011);
if(!defined("IDC_GROUPBOX4012")) define("IDC_GROUPBOX4012", 4012);
if(!defined("IDC_RADIOBUTTON4014")) define("IDC_RADIOBUTTON4014", 4014);
if(!defined("IDC_RADIOBUTTON4015")) define("IDC_RADIOBUTTON4015", 4015);
if(!defined("IDC_STATIC4019")) define("IDC_STATIC4019", 4019);
if(!defined("IDC_TOOLBAR4025")) define("IDC_TOOLBAR4025", 4025);
if(!defined("IDD_DLG4027")) define("IDD_DLG4027", 4027);
if(!defined("ID_TREE")) define("ID_TREE", 801);
if(!defined("IDC_HSCROLL4026")) define("IDC_HSCROLL4026", 4026);
if(!defined("IDC_UPDOWN4028")) define("IDC_UPDOWN4028", 4028);
if(!defined("IDC_EDIT4030")) define("IDC_EDIT4030", 4030);
if(!defined("IDC_CHECKBOX4034")) define("IDC_CHECKBOX4034", 4034);
if(!defined("IDC_RADIOBUTTON4016")) define("IDC_RADIOBUTTON4016", 4016);
if(!defined("IDC_STATIC4048")) define("IDC_STATIC4048", 4048);
if(!defined("IDC_CHECKBOX4049")) define("IDC_CHECKBOX4049", 4049);
if(!defined("IDC_VSCROLL4051")) define("IDC_VSCROLL4051", 4051);
if(!defined("IDC_EDIT4052")) define("IDC_EDIT4052", 4052);
if(!defined("IDC_LISTBOX4053")) define("IDC_LISTBOX4053", 4053);
if(!defined("IDC_COMBOBOX4054")) define("IDC_COMBOBOX4054", 4054);
if(!defined("IDC_LISTBOX4055")) define("IDC_LISTBOX4055", 4055);
if(!defined("IDC_HSCROLL4056")) define("IDC_HSCROLL4056", 4056);
if(!defined("IDC_EDIT4057")) define("IDC_EDIT4057", 4057);
if(!defined("IDC_EDIT4058")) define("IDC_EDIT4058", 4058);
if(!defined("IDC_EDIT4059")) define("IDC_EDIT4059", 4059);
if(!defined("IDC_EDIT4060")) define("IDC_EDIT4060", 4060);
if(!defined("IDC_RICHEDIT4061")) define("IDC_RICHEDIT4061", 4061);
if(!defined("IDC_RICHEDIT4062")) define("IDC_RICHEDIT4062", 4062);
if(!defined("IDC_STATIC4063")) define("IDC_STATIC4063", 4063);
if(!defined("IDC_STATIC4064")) define("IDC_STATIC4064", 4064);
if(!defined("IDC_EDIT4065")) define("IDC_EDIT4065", 4065);

// Create window

wbtemp_create_item($maintab, "Test values");

// Insert controls

wb_create_control($maintab, Frame, "Group box", 4, 6, 111, 141, IDC_GROUPBOX4012, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Gauge, "IDC_PROGRESSBAR4007", 155, 36, 104, 14, IDC_PROGRESSBAR4007, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Slider, "IDC_SLIDER4011", 120, 68, 146, 26, IDC_SLIDER4011, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &1", 19, 29, 92, 14, IDC_RADIOBUTTON4014, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &2", 19, 50, 92, 19, IDC_RADIOBUTTON4015, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "0", 120, 36, 27, 14, IDC_STATIC4019, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT, 2);
wb_create_control($maintab, ScrollBar, "IDC_HSCROLL4026", 125, 9, 137, 16, IDC_HSCROLL4026, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "0", 120, 104, 40, 19, IDC_EDIT4030, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, Spinner, "", 163, 104, 16, 19, IDC_UPDOWN4028, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, CheckBox, "Checkbox 1", 19, 100, 92, 14, IDC_CHECKBOX4034, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, RadioButton, "Option &3", 19, 73, 92, 19, IDC_RADIOBUTTON4016, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "(Values)", 4, 206, 282, 26, IDC_STATIC4048, WBC_VISIBLE | WBC_ENABLED | WBC_LINES, 2);
wb_create_control($maintab, CheckBox, "Checkbox 2", 19, 121, 92, 14, IDC_CHECKBOX4049, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ScrollBar, "", 271, 4, 16, 127, IDC_VSCROLL4051, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "0", 206, 104, 40, 19, IDC_EDIT4052, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, ListBox, "", 297, 4, 75, 52, IDC_LISTBOX4053, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ComboBox, "", 377, 4, 131, 196, IDC_COMBOBOX4054, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ListBox, "", 377, 31, 131, 21, IDC_LISTBOX4055, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, ScrollBar, "IDC_HSCROLL4056", 120, 131, 146, 16, IDC_HSCROLL4056, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "Pack my box with five dozen liquor jugs", 4, 154, 131, 21, IDC_EDIT4057, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, EditBox, "", 4, 177, 131, 21, IDC_EDIT4058, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY, 2);
wb_create_control($maintab, EditBox, "", 140, 154, 146, 21, IDC_EDIT4059, WBC_VISIBLE | WBC_ENABLED | WBC_MASKED, 2);
wb_create_control($maintab, RTFEditBox, "", 297, 121, 237, 55, IDC_RICHEDIT4061, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY, 2);
wb_create_control($maintab, RTFEditBox, "", 297, 182, 237, 55, IDC_RICHEDIT4062, WBC_VISIBLE | WBC_ENABLED, 2);
wb_create_control($maintab, Label, "&Digits only:", 140, 182, 55, 21, IDC_STATIC4063, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT, 2);
wb_create_control($maintab, EditBox, "", 197, 177, 90, 21, IDC_EDIT4060, WBC_VISIBLE | WBC_ENABLED | WBC_NUMBER, 2);
wb_create_control($maintab, EditBox, "", 297, 62, 237, 55, IDC_EDIT4065, WBC_VISIBLE | WBC_DISABLED | WBC_LINES, 2);
wb_create_control($maintab, Label, "Drag me:", 164, 52, 60, 14, IDC_STATIC4064, WBC_VISIBLE | WBC_ENABLED | WBC_CENTER, 2);

// End controls


// Control identifiers

if(!defined("IDD_DLG5001")) define("IDD_DLG5001", 5001);
if(!defined("IDC_GROUPBOX5012")) define("IDC_GROUPBOX5012", 5012);
if(!defined("IDC_TOOLBAR5025")) define("IDC_TOOLBAR5025", 5025);
if(!defined("IDD_DLG5027")) define("IDD_DLG5027", 5027);
if(!defined("IDC_SHAPE5056")) define("IDC_SHAPE5056", 5056);
if(!defined("IDC_SHAPE5057")) define("IDC_SHAPE5057", 5057);
if(!defined("IDC_SHAPE5058")) define("IDC_SHAPE5058", 5058);
if(!defined("IDC_STATIC5060")) define("IDC_STATIC5060", 5060);
if(!defined("IDC_SHAPE5061")) define("IDC_SHAPE5061", 5061);
if(!defined("IDC_STATIC5062")) define("IDC_STATIC5062", 5062);
if(!defined("IDC_STATIC5063")) define("IDC_STATIC5063", 5063);
if(!defined("IDC_BUTTON5068")) define("IDC_BUTTON5068", 5069);
if(!defined("IDC_SHAPE5065")) define("IDC_SHAPE5065", 5065);
if(!defined("IDC_SHAPE5066")) define("IDC_SHAPE5066", 5066);
if(!defined("IDC_SHAPE5067")) define("IDC_SHAPE5067", 5067);
if(!defined("IDC_BUTTON5068")) define("IDC_BUTTON5068", 5068);
if(!defined("IDC_STATIC5070")) define("IDC_STATIC5070", 5070);
if(!defined("IDC_STATIC5071")) define("IDC_STATIC5071", 5071);

// Create window

wbtemp_create_item($maintab, "Static controls");

// Insert controls

wb_create_control($maintab, Frame, "", 126, 8, 120, 68, IDC_SHAPE5058, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "Group box", 4, 4, 111, 72, IDC_GROUPBOX5012, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "", 327, 9, 131, 3, IDC_SHAPE5056, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Frame, "", 468, 9, 1, 62, IDC_SHAPE5057, WBC_VISIBLE | WBC_ENABLED, 3);
$_tmp_ctrl_ = wb_create_control($maintab, Frame, "dn_arrow.bmp", 4, 141, 113, 45, IDC_STATIC5062, WBC_VISIBLE | WBC_ENABLED | WBC_BORDER | WBC_IMAGE | WBC_CENTER, 3);
wb_set_image($_tmp_ctrl_, '../res/dn_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($maintab, Label, "This text is centered.", 468, 80, 61, 36, IDC_STATIC5060, WBC_VISIBLE | WBC_ENABLED | WBC_CENTER, 3);
wb_create_control($maintab, Label, "For a 'sunken' frame or label, use Windows extended style, WS_EX_STATICEDGE.", 4, 85, 182, 45, IDC_SHAPE5061, WBC_VISIBLE | WBC_ENABLED | WBC_BORDER | WBC_LINES, 3);
$_tmp_ctrl_ = wb_create_control($maintab, Frame, "hyper.ico", 125, 141, 113, 45, IDC_STATIC5063, WBC_VISIBLE | WBC_ENABLED | WBC_IMAGE | WBC_CENTER, 3);
wb_set_image($_tmp_ctrl_, '../res/hyper.ico', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($maintab, Label, "This label control wraps words if they do not fit in the availble space.", 4, 196, 131, 45, IDC_SHAPE5065, WBC_VISIBLE | WBC_ENABLED | WBC_LINES, 3);
wb_create_control($maintab, Label, "This one does not wrap anything.", 140, 196, 152, 16, IDC_SHAPE5066, WBC_VISIBLE | WBC_ENABLED, 3);
wb_create_control($maintab, Label, "This one uses ellipsis to display the text.", 140, 221, 111, 21, IDC_SHAPE5067, WBC_VISIBLE | WBC_ENABLED | WBC_ELLIPSIS, 3);
wb_create_control($maintab, PushButton, "&Test", 366, 24, 77, 26, IDC_BUTTON5068, WBC_VISIBLE | WBC_ENABLED | WBC_BORDER, 3);
wb_create_control($maintab, PushButton, "&Test", 282, 24, 77, 26, IDC_BUTTON5068, WBC_VISIBLE | WBC_ENABLED, 3);
$_tmp_ctrl_ = wb_create_control($maintab, Frame, "up_arrow.bmp", 252, 136, 66, 50, IDC_STATIC5070, WBC_VISIBLE | WBC_ENABLED | WBC_IMAGE | WBC_CENTER, 3);
wb_set_image($_tmp_ctrl_, '../res/up_arrow.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($maintab, Label, "This text is right-aligned.", 372, 80, 86, 36, IDC_STATIC5071, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT, 3);

// End controls
// Control identifiers

if(!defined("IDD_DLG6001")) define("IDD_DLG6001", 6001);
if(!defined("IDC_EDIT6002")) define("IDC_EDIT6002", 6002);
if(!defined("ID_LOWLEVEL")) define("ID_LOWLEVEL", 6003);
if(!defined("ID_RESETHANDLER")) define("ID_RESETHANDLER", 6004);

// Create window

wbtemp_create_item($maintab, "Low-level");

// Insert controls

wb_create_control($maintab, PushButton, "Run &Tests", 10, 14, 81, 31, ID_LOWLEVEL, WBC_VISIBLE | WBC_ENABLED, 4);
wb_create_control($maintab, EditBox, "", 196, 9, 277, 218, IDC_EDIT6002, WBC_VISIBLE | WBC_ENABLED | WBC_LINES | WBC_READONLY, 4);
wb_create_control($maintab, PushButton, "Reset &Handler", 10, 50, 81, 31, ID_RESETHANDLER, WBC_VISIBLE | WBC_ENABLED, 4);

// End controls

?>
